@@ -168,11 +168,13 @@ class InstallIPythonKernelSpecApp(Application):
     name = Unicode("ipython-kernel-install")
 
     def initialize(self, argv=None):
+        """Initialize the app."""
         if argv is None:
             argv = sys.argv[1:]
         self.argv = argv
 
     def start(self):
+        """Start the app."""
         import argparse
 
         parser = argparse.ArgumentParser(
@@ -242,7 +244,7 @@ class InstallIPythonKernelSpecApp(Application):
                     print("Perhaps you want `sudo` or `--user`?", file=sys.stderr)
                 self.exit(1)
             raise
-        print("Installed kernelspec %s in %s" % (opts.name, dest))
+        print(f"Installed kernelspec {opts.name} in {dest}")
 
 
 if __name__ == "__main__":
