@@ -25,11 +25,11 @@ from IPython.core.displaypub import DisplayPublisher
 from IPython.core.error import UsageError
 from IPython.core.interactiveshell import InteractiveShell, InteractiveShellABC
 from IPython.core.magic import Magics, line_magic, magics_class
-from IPython.core.magics import CodeMagics, MacroToEdit
+from IPython.core.magics import CodeMagics, MacroToEdit  # type:ignore[attr-defined]
 from IPython.core.usage import default_banner
-from IPython.display import Javascript, display
+from IPython.display import Javascript, display  # type:ignore[attr-defined]
 from IPython.utils import openpy
-from IPython.utils.process import arg_split, system
+from IPython.utils.process import arg_split, system  # type:ignore[attr-defined]
 from jupyter_client.session import Session, extract_header
 from jupyter_core.paths import jupyter_runtime_dir
 from traitlets import Any, CBool, CBytes, Dict, Instance, Type, default, observe
@@ -194,6 +194,8 @@ class ZMQDisplayPublisher(DisplayPublisher):
 
 @magics_class
 class KernelMagics(Magics):
+    """Kernel magics."""
+
     # ------------------------------------------------------------------------
     # Magic overrides
     # ------------------------------------------------------------------------
@@ -202,8 +204,6 @@ class KernelMagics(Magics):
     # the magics which this class needs to implement differently from the base
     # class, or that are unique to it.
 
-    _find_edit_target = CodeMagics._find_edit_target
-
     @line_magic
     def edit(self, parameter_s="", last_call=None):
         """Bring up an editor and execute the resulting code.
@@ -296,6 +296,7 @@ class KernelMagics(Magics):
         filename = os.path.abspath(filename)
 
         payload = {"source": "edit_magic", "filename": filename, "line_number": lineno}
+        assert self.shell is not None
         self.shell.payload_manager.write_payload(payload)
 
     # A few magics that are adapted to the specifics of using pexpect and a
@@ -304,6 +305,7 @@ class KernelMagics(Magics):
     @line_magic
     def clear(self, arg_s):
         """Clear the terminal."""
+        assert self.shell is not None
         if os.name == "posix":
             self.shell.system("clear")
         else:
@@ -321,12 +323,15 @@ class KernelMagics(Magics):
 
         Files ending in .py are syntax-highlighted."""
         if not arg_s:
-            raise UsageError("Missing filename.")
+            msg = "Missing filename."
+            raise UsageError(msg)
 
         if arg_s.endswith(".py"):
+            assert self.shell is not None
             cont = self.shell.pycolorize(openpy.read_py_file(arg_s, skip_encoding_cookie=False))
         else:
-            cont = open(arg_s).read()
+            with open(arg_s) as fid:
+                cont = fid.read()
         page.page(cont)
 
     more = line_magic("more")(less)
@@ -337,6 +342,7 @@ class KernelMagics(Magics):
         @line_magic
         def man(self, arg_s):
             """Find the man page for the given command and display in pager."""
+            assert self.shell is not None
             page.page(self.shell.getoutput("man %s | col -b" % arg_s, split=False))
 
     @line_magic
@@ -429,7 +435,7 @@ class ZMQInteractiveShell(InteractiveShell):
 
     displayhook_class = Type(ZMQShellDisplayHook)
     display_pub_class = Type(ZMQDisplayPublisher)
-    data_pub_class = Any()
+    data_pub_class = Any()  # type:ignore[assignment]
     kernel = Any()
     parent_header = Any()
 
@@ -468,6 +474,7 @@ class ZMQInteractiveShell(InteractiveShell):
     # Over ZeroMQ, GUI control isn't done with PyOS_InputHook as there is no
     # interactive input being read; we provide event loop support in ipkernel
     def enable_gui(self, gui):
+        """Enable a given guil."""
         from .eventloops import enable_gui as real_enable_gui
 
         try:
@@ -482,6 +489,9 @@ class ZMQInteractiveShell(InteractiveShell):
         # These two ensure 'ls' produces nice coloring on BSD-derived systems
         env["TERM"] = "xterm-color"
         env["CLICOLOR"] = "1"
+        # These two add terminal color in tools that support it.
+        env["FORCE_COLOR"] = "1"
+        env["CLICOLOR_FORCE"] = "1"
         # Since normal pagers don't work at all (over pexpect we don't have
         # single-key control of the subprocess), try to disable paging in
         # subprocesses as much as possible.
@@ -489,6 +499,7 @@ class ZMQInteractiveShell(InteractiveShell):
         env["GIT_PAGER"] = "cat"
 
     def init_hooks(self):
+        """Initialize hooks."""
         super().init_hooks()
         self.set_hook("show_in_pager", page.as_hook(payloadpage.page), 99)
 
@@ -505,7 +516,7 @@ class ZMQInteractiveShell(InteractiveShell):
                 stacklevel=2,
             )
 
-            self._data_pub = self.data_pub_class(parent=self)
+            self._data_pub = self.data_pub_class(parent=self)  # type:ignore[has-type]
             self._data_pub.session = self.display_pub.session
             self._data_pub.pub_socket = self.display_pub.pub_socket
         return self._data_pub
@@ -524,6 +535,7 @@ class ZMQInteractiveShell(InteractiveShell):
         self.payload_manager.write_payload(payload)
 
     def run_cell(self, *args, **kwargs):
+        """Run a cell."""
         self._last_traceback = None
         return super().run_cell(*args, **kwargs)
 
@@ -584,14 +596,17 @@ class ZMQInteractiveShell(InteractiveShell):
             pass
 
     def get_parent(self):
+        """Get the parent header."""
         return self.parent_header
 
     def init_magics(self):
+        """Initialize magics."""
         super().init_magics()
         self.register_magics(KernelMagics)
         self.magics_manager.register_alias("ed", "edit")
 
     def init_virtualenv(self):
+        """Initialize virtual environment."""
         # Overridden not to do virtualenv detection, because it's probably
         # not appropriate in a kernel. To use a kernel in a virtualenv, install
         # it inside the virtualenv.
@@ -614,7 +629,8 @@ class ZMQInteractiveShell(InteractiveShell):
             # pexpect or pipes to read from.  Users can always just call
             # os.system() or use ip.system=ip.system_raw
             # if they really want a background process.
-            raise OSError("Background processes not supported.")
+            msg = "Background processes not supported."
+            raise OSError(msg)
 
         # we explicitly do NOT return the subprocess status code, because
         # a non-None value would trigger :func:`sys.displayhook` calls.
@@ -627,7 +643,7 @@ class ZMQInteractiveShell(InteractiveShell):
 
             with AvoidUNCPath() as path:
                 if path is not None:
-                    cmd = "pushd %s &&%s" % (path, cmd)
+                    cmd = f"pushd {path} &&{cmd}"
                 self.user_ns["_exit_code"] = system(cmd)
         else:
             self.user_ns["_exit_code"] = system(self.var_expand(cmd, depth=1))
